Projects - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Projects

A project contains all the information necessary to turn a family tree into a site. After installing Betty once, you can manage multiple projects.

You can create and tailor projects through the Betty Desktop application, or through the command line using configuration files.

Important

Betty will consider the directory your project configuration file is located in to be your project directory, and assumes that the directory will not be used for anything else besides your Betty project.

## The project directory

`./assets/`

  Your project’s assets, through which you can override translations, HTML templates, and more.

`./betty.yaml` or `./betty.yml` or `./betty.json`

  Your project’s configuration file.

`./output/`

  This is where Betty puts all the things it generates for you.

`./output/www`

  This is where Betty puts your generated site.

## In this section

- Project configuration